import json
import os

__location__ = os.path.realpath(os.path.join(os.getcwd(), os.path.dirname(__file__)))


def _load_json(path):
    with open(path, "r") as f:
        return json.load(f)


def _load_webhook_names():
    webhooks = _load_json(os.path.join(__location__, "webhooks", "index.json"))
    webhook_names = ["*"]
    webhook_names += [m["name"] + ".{}".format(n) for m in webhooks for n in m["actions"]]
    webhook_names += [m["name"] for m in webhooks if m["actions"] == []]
    return webhook_names


def _load_spec(spec_name):
    return _load_json(os.path.join(__location__, "routes", spec_name))


def _list_specs():
    return [
        d.name for d in os.scandir(os.path.join(__location__, "routes")) if d.is_file() and not d.name.endswith("js")
    ]


specs = _list_specs()
specifications = {spec.replace(".json", ""): _load_spec(spec) for spec in specs}

webhook_names = _load_webhook_names()



#!/usr/bin/env python

from setuptools import setup


setup(
    name='octokitpy-routes',
    version='2.4.0',
    description='Routes for octokitpy',
    long_description='Routes from the NPM published octokit routes',
    author='Kyle Hornberg',
    author_email='kyle.hornberg@gmail.com',
    url='https://github.com/khornberg/octokitpy-routes',
    packages=['octokit_routes'],
    include_package_data=True,
    classifiers=[
        # complete classifier list: http://pypi.python.org/pypi?%3Aaction=list_classifiers
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Topic :: Utilities',
    ]
)
